@@ -12,18 +12,34 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import sys
+from os import path
+
 import robot
 
-from testbench2robotframework.utils import arg_parser
-from testbench2robotframework.testbench2robotframework import testbench2robotframework
 from testbench2robotframework import __version__
 
+from .config import write_default_config
+from .json_reader import read_json
+from .robotframework2testbench import robot2testbench
+from .testbench2robotframework import testbench2robotframework
+from .utils import arg_parser
+
 
 def run():
     args = arg_parser.parse_args()
+    if args.subcommand is None and not args.version:
+        arg_parser.print_help()
+        sys.exit()
     if args.version:
         print_version()
-    testbench2robotframework(args.jsonReport, args.config)
+        sys.exit()
+    if not path.isfile(args.config):
+        write_default_config(args.config)
+    configuration = read_json(args.config)
+    if args.subcommand == 'write':
+        testbench2robotframework(args.jsonReport[0], configuration)
+    elif args.subcommand == 'read':
+        robot2testbench(args.jsonReport[0], args.output, args.result, configuration)
 
 
 def print_version():
@@ -31,7 +47,6 @@ def print_version():
         f'TestBench2RobotFramework {__version__} with '
         f'[Robot Framework {robot.version.get_full_version()}]'
     )
-    sys.exit()
 
 
 if __name__ == "__main__":
