@@ -3,7 +3,8 @@ from __future__ import annotations
 
 import json
 from dataclasses import dataclass
-from typing import Dict, List
+from typing import Dict, List, Union
+
 from .model import StrEnum
 
 
@@ -60,7 +61,7 @@ class ConsoleLoggerConfig:
             )
             log_level = LogLevel.INFO
         return cls(
-            logLevel=log_level,
+            logLevel=LogLevel(log_level),
             logFormat=dictionary.get("logFormat", "%(levelname)s: %(message)s"),
         )
 
@@ -100,8 +101,23 @@ class LoggingConfig:
         )
 
 
+class ReferenceBehaviour(StrEnum):
+    ATTACHMENT = "ATTACHMENT"
+    REFERENCE = "REFERENCE"
+    NONE = "NONE"
+
+
+class AttachmentConflictBehaviour(StrEnum):
+    ERROR = "ERROR"
+    USE_NEW = "USE_NEW"
+    USE_EXISTING = "USE_EXISTING"
+    RENAME_NEW = "RENAME_NEW"
+
+
 @dataclass
 class Configuration:
+    rfLibraryRegex: List[str]
+    rfResourceRegex: List[str]
     rfLibraryRoots: List[str]
     rfResourceRoots: List[str]
     fullyQualified: bool
@@ -116,12 +132,20 @@ class Configuration:
     logCompoundInteractions: bool
     testCaseSplitPathRegEx: str
     phasePattern: str
+    referenceBehaviour: ReferenceBehaviour
+    attachmentConflictBehaviour: AttachmentConflictBehaviour
 
     @classmethod
     def from_dict(cls, dictionary) -> Configuration:
         return cls(
-            rfLibraryRoots=dictionary.get("rfLibraryRoots", []),
-            rfResourceRoots=dictionary.get("rfResourceRoots", []),
+            rfLibraryRegex=dictionary.get(
+                "rfLibraryRegex", [r"(?:.*\.)?(?P<resourceName>[^.]+?)\s*\[Robot-Library\].*"]
+            ),
+            rfResourceRegex=dictionary.get(
+                "rfResourceRegex", [r"(?:.*\.)?(?P<resourceName>[^.]+?)\s*\[Robot-Resource\].*"]
+            ),
+            rfLibraryRoots=dictionary.get("rfLibraryRoots", ["RF", "RF-Library"]),
+            rfResourceRoots=dictionary.get("rfResourceRoots", ["RF-Resource"]),
             fullyQualified=dictionary.get("fullyQualified", False),
             subdivisionsMapping=SubdivisionsMapping.from_dict(
                 dictionary.get("subdivisionsMapping", {})
@@ -140,6 +164,12 @@ class Configuration:
             ),
             testCaseSplitPathRegEx=dictionary.get("testCaseSplitPathRegEx", ".*StopWithRestart.*"),
             phasePattern=dictionary.get("phasePattern", "{testcase} : Phase {index}/{length}"),
+            referenceBehaviour=ReferenceBehaviour(
+                dictionary.get("referenceBehaviour", "ATTACHMENT").upper()
+            ),
+            attachmentConflictBehaviour=AttachmentConflictBehaviour(
+                dictionary.get("attachmentConflictBehaviour", "USE_EXISTING").upper()
+            ),
         )
 
 
