@@ -239,12 +239,20 @@ class RfTestCase:
     def _create_cbv_parameters(interaction: AtomicInteractionCall) -> List[str]:
         parameters = []
         for name, value in interaction.cbv_parameters.items():
+            escaped_value = RfTestCase.escape_argument_value(value)
             if name.endswith('='):
-                parameters.append(f"{name}{value}")
+                parameters.append(f"{name}{escaped_value}")
             else:
-                parameters.append(value)
+                parameters.append(escaped_value)
         return parameters
 
+    @staticmethod
+    def escape_argument_value(value: str) -> str:
+        value = re.sub(r'(?<!\\)=', r'\=', value)
+        value = re.sub(r'^#', r'\#', value)
+        value = re.sub(r'(?<= ) ', r'\ ', value)
+        return value
+
     @staticmethod
     def _create_cbr_parameters(interaction: AtomicInteractionCall) -> List[str]:
         cbr_parameters = list(interaction.cbr_parameters.values())
